Learn R Programming

samadb (version 0.3.1)

.SAMADB_ID: Global Identifier Macros

Description

The macro .SAMADB_ID contains the string c("dsid", "series") denoting the names of ID variables that identify the cross-sectional dimension in the database. All series codes are unique across datasets.

The macro .SAMADB_T contains the string c("date", "year", "quarter", "month", "day") denoting temporal identifiers generated by sm_expand_date. The "date" variable is sufficient to uniquely identify a point in time in the database.

Each value in the database is uniquely identified by dsid, series and date.

Usage

.SAMADB_ID
.SAMADB_T

Arguments

See Also

samadb

Examples

Run this code
.SAMADB_ID
.SAMADB_T


Run the code above in your browser using DataLab