The macro .SAMADB_ID contains the string c("dsid", "series") denoting
the names of ID variables that identify the cross-sectional dimension in the database. All series codes are unique across datasets.
The macro .SAMADB_T contains the string
c("date", "year", "quarter", "month", "day") denoting temporal identifiers generated by sm_expand_date.
The "date" variable is sufficient to uniquely identify a point in time in the database.
Each value in the database is uniquely identified by dsid, series and date.